==> knative-model-4.12.0-sources.jar: io/fabric8/knative/serving/v1/RevisionListBuilder.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RevisionListBuilder extends RevisionListFluentImpl<RevisionListBuilder> implements VisitableBuilder<RevisionList,RevisionListBuilder> {

    RevisionListFluent<?> fluent;
    Boolean validationEnabled;

    public RevisionListBuilder() { 
        this(true);
    }


    public RevisionListBuilder(Boolean validationEnabled) { 
        this(new RevisionList(), validationEnabled);
    }


    public RevisionListBuilder(RevisionListFluent<?> fluent) { 
        this(fluent, true);
    }


    public RevisionListBuilder(RevisionListFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new RevisionList(), validationEnabled);
    }


    public RevisionListBuilder(RevisionListFluent<?> fluent,RevisionList instance) { 
        this(fluent, instance, true);
    }


    public RevisionListBuilder(RevisionListFluent<?> fluent,RevisionList instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public RevisionListBuilder(RevisionList instance) { 
        this(instance,true);
    }


    public RevisionListBuilder(RevisionList instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public RevisionList build() {
        RevisionList buildable = new RevisionList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RevisionListBuilder that = (RevisionListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.0.2-sources.jar: io/fabric8/knative/serving/v1/RevisionListBuilder.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RevisionListBuilder extends RevisionListFluentImpl<RevisionListBuilder> implements VisitableBuilder<RevisionList,RevisionListBuilder> {

    RevisionListFluent<?> fluent;
    Boolean validationEnabled;

    public RevisionListBuilder() {
        this(true);
    }

    public RevisionListBuilder(Boolean validationEnabled) {
        this(new RevisionList(), validationEnabled);
    }

    public RevisionListBuilder(RevisionListFluent<?> fluent) {
        this(fluent, true);
    }

    public RevisionListBuilder(RevisionListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new RevisionList(), validationEnabled);
    }

    public RevisionListBuilder(RevisionListFluent<?> fluent,RevisionList instance) {
        this(fluent, instance, true);
    }

    public RevisionListBuilder(RevisionListFluent<?> fluent,RevisionList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public RevisionListBuilder(RevisionList instance) {
        this(instance,true);
    }

    public RevisionListBuilder(RevisionList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.serving.v1.EditableRevisionList build() {
        EditableRevisionList buildable = new EditableRevisionList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RevisionListBuilder that = (RevisionListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
